@@ -45,20 +45,21 @@ class _GIMeta(SingletonMeta):
         if not isinstance(pn, str):
             msg = '{}.package_name is of wrong type'.format(name)
             raise TypeError(msg)
-        if not re.match(r'\w[\w.]*\w', pn):
+        if not re.match(r'\w[\w.]*\w$', pn):
             msg = 'invalid {}.package_name: "{}"'.format(name, pn)
             raise ValueError(msg)
         return super().__new__(mcs, name, bases, attrs)
 
 
 class _PackageNameDerivant:
-    __slots__ = ['_sep']
+    __slots__ = ['sep']
+    regex = re.compile(r'[._]+')
 
-    def __init__(self, sep):
-        self._sep = sep
+    def __init__(self, sep: str):
+        self.sep = sep
 
-    def __get__(self, _, owner):
-        return owner.package_name.replace('.', self._sep)
+    def __get__(self, _, owner: 'GlobalInterface'):
+        return self.regex.sub(self.sep, owner.package_name)
 
 
 class GlobalInterface(metaclass=_GIMeta):
@@ -66,11 +67,11 @@ class GlobalInterface(metaclass=_GIMeta):
     package_name = 'volkanic'
 
     # for path and url
-    # dot '.' in package_name replaced by hyphen '-'
+    # '[._]+' in package_name replaced by hyphen '-'
     project_name = _PackageNameDerivant('-')
 
     # for symbols in code
-    # dot '.' in package_name replaced by underscore '_'
+    # '[._]+' in package_name replaced by underscore '_'
     identifier = _PackageNameDerivant('_')
 
     _options = {
@@ -78,8 +79,6 @@ class GlobalInterface(metaclass=_GIMeta):
         'project_source_depth': 0,
         # for config file locating (_get_conf_paths())
         'confpath_filename': 'config.json5',
-        # for config file locating (_get_conf_paths())
-        'confpath_dirname_sep': '-',
     }
 
     # default config and log format
@@ -102,9 +101,17 @@ class GlobalInterface(metaclass=_GIMeta):
             except (KeyError, TypeError):
                 pass
 
+    @classmethod
+    def _split_name(cls):
+        return _PackageNameDerivant.regex.split(cls.package_name)
+
     @classmethod
     def _fmt_name(cls, sep='-'):
-        return cls.package_name.replace('.', sep)
+        return _PackageNameDerivant.regex.sub(sep, cls.package_name)
+
+    @classmethod
+    def _get_conf_path_names(cls):
+        return [cls.project_name, cls._get_option('confpath_filename')]
 
     @classmethod
     def _get_conf_paths(cls):
@@ -113,14 +120,14 @@ class GlobalInterface(metaclass=_GIMeta):
         Override this method in your subclasses for your specific project.
         """
         envvar_name = cls._fmt_envvar_name('confpath')
-        fn = cls._get_option('confpath_filename')
-        pn = cls._fmt_name(cls._get_option('confpath_dirname_sep'))
+        names = cls._get_conf_path_names()
+        relative_path = os.path.join(*names)
         return [
             os.environ.get(envvar_name),
-            cls.under_project_dir(fn),
-            utils.under_home_dir('.{}/{}'.format(pn, fn)),
-            '/etc/{}/{}'.format(pn, fn),
-            '/{}/{}'.format(pn, fn),
+            cls.under_project_dir(names[-1]),
+            utils.under_home_dir('.' + relative_path),
+            os.path.join('/etc', relative_path),
+            os.path.join('/', relative_path),
         ]
 
     # _get_conf_search_paths is deprecated
@@ -183,6 +190,33 @@ class GlobalInterface(metaclass=_GIMeta):
         paths = ['..'] * n + list(paths)
         return utils.abs_path_join(pkg_dir, *paths)
 
+    @classmethod
+    def _get_self(cls):
+        mcs = cls.__class__
+        try:
+            return mcs.registered_instances[cls]
+        except KeyError:
+            pass
+
+    @classmethod
+    def debug(cls) -> dict:
+        try:
+            conf = cls._get_self().__dict__['conf']
+        except (AttributeError, KeyError):
+            conf = None
+        mcs = cls.__class__
+        return {
+            'identifier': cls.identifier,
+            'package_name': cls.package_name,
+            'project_name': cls.project_name,
+            'project_dir': cls.under_project_dir(),
+            'package_dir': cls.under_package_dir(),
+            'registered_instances': mcs.registered_instances,
+            'conf_paths': cls._get_conf_paths(),
+            'conf_path': cls._locate_conf(),
+            'conf': conf,
+        }
+
     # deprecated
     # this method will be removed at ver 0.5.0
     @cached_property
@@ -243,3 +277,10 @@ class GIMixinDirs:
     # both will be removed
     get_temp_path = under_temp_dir
     under_temp_path = under_temp_dir
+
+
+class GlobalInterfaceTrial(GlobalInterface, GIMixinDirs):
+    package_name = 'volkanic'
+
+
+GlobalInterfacePlus = GlobalInterfaceTrial
